
/*
Remove ID cols from an insert stmt.
Here inserting the ID is causing some issues so we need to just get rid of that col and let
the table manage the IDs for us.
The only problem is that there's more than 1 table being inserted in this script, so we have to
make sure that the only ones that get changed are the ones at the beginning for Archive.Config.

We've got a couple things here that we can take advantage of:
1. The stmts are formatted the same.
2. the insert cols are all the same.

This allows us to attack this in a simple fashion.  We need to get rid of the col in the 
insert list and in the values list.  And we can get rid of them in a single go.
All we have to do is put them all into separate groups and then rebuild the stmts in the replace
text.

Search for: (INSERT \[Archive\].\[Config\] \()(\[ID\], )(\[SchemaName\], \[TableName\], \[ArchiveDays\], \[RowsInBatch\]\) VALUES \()(\d+, )(.+)
Replace with: $1$3$5

These are all capture groups.  And that means that we need to capture the ID in the insert and
the ID in the values separately so we can rebuild the stmt without them.

Below you can see the groups and their capture numbers.
(INSERT \[Archive\].\[Config\] \() -- $1
(\[ID\], ) -- $2 --This is the ID col in the INSERT list.
(\[SchemaName\], \[TableName\], \[ArchiveDays\], \[RowsInBatch\]\) VALUES \() -- $3
(\d+, ) -- $4 --This is the ID col in the VALUES list.
(.+) -- $5

A couple notes:
1. We have to escape the [] and the () chars in the search expression.
2. We're using .+ in the last one so we can just pick up any stray chars at the end.  At this point
we don't care what those are, we just want the rest of the stmt to come over as-is.
*/
 
SET NOCOUNT ON;
SET IDENTITY_INSERT [Archive].[Config] ON 

GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'TableSize')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (2, N'Collector', 'TableSize', 730, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'DriveSpace')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (3, N'Collector', 'DriveSpace', 365, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'DBProperties')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (4, N'Collector', 'DBProperties', 365, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'DBFileProperties')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (5, N'Collector', 'DBFileProperties', 365, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'Databases')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (6, N'Collector', 'Databases', 365, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'DBUsers')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (7, N'Collector', 'DBUsers', 90, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'Logins')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (8, N'Collector', 'Logins', 180, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'ServiceStatus')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (9, N'Collector', 'ServiceStatus', 90, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'ServiceAlert')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (10, N'Collector', 'ServiceAlert', 60, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'IndexMaintLog')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (11, N'Collector', 'IndexMaintLog', 60, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'IndexMaintLogDetails')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (12, N'Collector', 'IndexMaintLogDetails', 60, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'CheckDBResult')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (14, N'Collector', 'CheckDBResult', 365, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'ReplLatency')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (15, N'Collector', 'ReplLatency', 60, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'WaitStats')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (16, N'Collector', 'WaitStats', 90, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'SysObjects')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (17, N'Collector', 'SysObjects', 60, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'ADGroupMember')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (18, N'Collector', 'ADGroupMember', 180, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'IndexStats')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (19, N'Collector', 'IndexStats', 60, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'ErrorLog')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (20, N'Collector', 'ErrorLog', 60, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'FileGrowthRate')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (21, N'Collector', 'FileGrowthRate', 60, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'LogSpace')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (22, N'Collector', 'LogSpace', 60, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'ServersOSDetail')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (23, N'Collector', 'ServersOSDetail', 60, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'DBSize')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (24, N'Collector', 'DBSize', 90, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'DBUsers')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (25, N'Collector', 'DBUsers', 90, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'InstanceConfig')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (26, N'Collector', 'InstanceConfig', 30, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'ServiceAcct')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (27, N'Collector', 'ServiceAcct', 60, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'TableColumns')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (28, N'Collector', 'TableColumns', 60, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'ServiceProperties')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (29, N'Collector', 'ServiceProperties', 60, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='History' AND TableName = 'ServiceStatus')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (30, N'History', 'ServiceStatus', 60, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Archive' AND TableName = 'Servers')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (31, N'Archive', 'Servers', 60, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='History' AND TableName = 'InstanceConfig')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (32, N'History', 'InstanceConfig', 60, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='History' AND TableName = 'DriveFreeSpace')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (33, N'History', 'DriveFreeSpace', 60, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='History' AND TableName = 'DBsNewRetired')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (34, N'History', 'DBsNewRetired', 60, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='History' AND TableName = 'WeakSQLPasswords')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (35, N'History', 'WeakSQLPasswords', 365, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='History' AND TableName = 'Backups')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (36, N'History', 'Backups', 90, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'AvailabilityReadOnlyRoutingLists')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (37, N'Collector', 'AvailabilityReadOnlyRoutingLists', 60, 10000)
END
GO																												  
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'DMHadrInstanceNodeMap')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (38, N'Collector', 'DMHadrInstanceNodeMap', 60, 10000)
END
GO																												  
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'DMTcpListenerStates')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (39, N'Collector', 'DMTcpListenerStates', 60, 10000)
END
GO																												  
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'AvailabilityGroupListeners')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (40, N'Collector', 'AvailabilityGroupListeners', 60, 10000)
END
GO																												  
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'AvailabilityGroupListenerIPAddresses')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (41, N'Collector', 'AvailabilityGroupListenerIPAddresses', 60, 10000)
END
GO																												  
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'DMHadrDatabaseReplicaClusterStates')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (42, N'Collector', 'DMHadrDatabaseReplicaClusterStates', 60, 10000)
END
GO																												  
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'DMHadrDatabaseReplicaStates')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (43, N'Collector', 'DMHadrDatabaseReplicaStates', 60, 10000)
END
GO																												   
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'DMHadrAvailabilityReplicaStates')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (44, N'Collector', 'DMHadrAvailabilityReplicaStates', 60, 10000)
END
GO																												   
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'DMHadrAvailabilityReplicaClusterStates')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (45, N'Collector', 'DMHadrAvailabilityReplicaClusterStates', 60, 10000)
END
GO																												   
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'DMHadrAvailabilityReplicaClusterNodes')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (46, N'Collector', 'DMHadrAvailabilityReplicaClusterNodes', 60, 10000)
END
GO																												   
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'AvailabilityReplicas')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (47, N'Collector', 'AvailabilityReplicas', 60, 10000)
END
GO																												   
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'DMHadrAvailabilityGroupStates')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (48, N'Collector', 'DMHadrAvailabilityGroupStates', 60, 10000)
END
GO																												   
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'AvailabilityGroupsCluster')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (49, N'Collector', 'AvailabilityGroupsCluster', 60, 10000)
END
GO																												   
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'AvailabilityGroups')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (50, N'Collector', 'AvailabilityGroups', 60, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'DMHadrClusterNetworks')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (51, N'Collector', 'DMHadrClusterNetworks', 60, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'DMHadrClusterMembers')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (52, N'Collector', 'DMHadrClusterMembers', 60, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'DMHadrCluster')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (53, N'Collector', 'DMHadrCluster', 60, 10000)
END
GO
IF NOT EXISTS (SELECT * FROM Archive.Config WHERE SchemaName='Collector' AND TableName = 'DBObjectScripts')
BEGIN
INSERT [Archive].[Config] ([ID], [SchemaName], [TableName], [ArchiveDays], [RowsInBatch]) VALUES (54, N'Collector', 'DBObjectScripts', 60, 10000)
END
GO
SET IDENTITY_INSERT [Archive].[Config] OFF
GO

-----------------------------ServerMgmtDB----------------------------------------
IF (SELECT COUNT(*) FROM dbo.ServerMgmtDB) = 0
BEGIN
	INSERT dbo.ServerMgmtDB (InstanceID, MgmtDB)
	VALUES (0, 'master')
END
GO
-----------------------------MinionVersion---------------------------------------

--------------------------BackupReport-------------------------------------------
IF (SELECT COUNT(*) FROM dbo.BackupReport) = 0
BEGIN
	INSERT [dbo].[BackupReport] ([InstanceID], [DBName], [ReportFull], [ReportDiff], [ReportLog], [FullAlertThresholdInHrs], [DiffAlertThresholdInHrs], [LogAlertThresholdInMins], [IsActive], [Comment])
	VALUES (0, N'MinionDefault', 1, 1, 1, 168, 24, 4, 1, N'MINION DEFAULT. DO NOT REMOVE.'),
	(0, N'master', 1, 0, 0, 24, 0, 0, 1, N'MINION DEFAULT. DO NOT REMOVE.')
END
GO

----------------BEGIN CheckDB Alert Thresholds--------------------
IF (SELECT COUNT(*) FROM dbo.CheckDBReport) = 0
BEGIN
	INSERT INTO [dbo].[CheckDBReport] (InstanceID, DBName, Report, CheckDBAlertThresholdInHrs, CheckTableAlertThresholdInHrs, SchemaName, TableName, IsActive, Comment)
	VALUES
	( 0, 'MinionDefault', 1, 168, 168, NULL, NULL, 1, 'MINION DEFAULT. DO NOT REMOVE.' ), 
	( 0, 'tempdb', 0, NULL, NULL, NULL, NULL, 1, 'Don''t report on tempdb globally.' ),
	( 0, 'ReportServertempdb', 0, NULL, NULL, NULL, NULL, 1, 'Don''t report on ReportServertempdb globally.' )
END
----------------END CheckDB Alert Thresholds----------------------
--------------------------------------------------------------------------------------------------------------------------------------------------------------------
--------------------------------------------------------------------------------------------------------------------------------------------------------------------
----------------------------BEGIN Conn Parameters-------------------------------------------------------------------------------------------------------------------
--------------------------------------------------------------------------------------------------------------------------------------------------------------------
--------------------------------------------------------------------------------------------------------------------------------------------------------------------
----To keep dupes out this should be switched to maybe an upsert process.  Load these rows into a #table and then do an upsert from there.
/*********************
1
*********************/

	IF NOT EXISTS (SELECT * FROM dbo.ConnParameters WHERE CollectionName='Collector.SysObjects')
	INSERT  INTO dbo.ConnParameters
			( InstanceID, CollectionName, UserName, PWord, ConnTimeout, PacketSize,
			  AppName, Asynch, AppIntent, Authentication, ConnRetryCT,
			  ConnRetryInterval, Encrypt, MultiSubnetFailover, TrustServerCert,
			  IsActive, Comment )
	VALUES (0, 'Collector.SysObjects', 'SSPI', 'SSPI', NULL, NULL, 'Minion: Collector.SysObjects', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1, 'MINION DEFAULT. DO NOT REMOVE.');
/*********************
2
*********************/

	IF NOT EXISTS (SELECT * FROM dbo.ConnParameters WHERE CollectionName='Collector.SysColumns')
	INSERT  INTO dbo.ConnParameters
			( InstanceID, CollectionName, UserName, PWord, ConnTimeout, PacketSize,
			  AppName, Asynch, AppIntent, Authentication, ConnRetryCT,
			  ConnRetryInterval, Encrypt, MultiSubnetFailover, TrustServerCert,
			  IsActive, Comment )
	VALUES (0, 'Collector.SysColumns', 'SSPI', 'SSPI', NULL, NULL, 'Minion: Collector.SysColumns', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1, 'MINION DEFAULT. DO NOT REMOVE.');
/*********************
3
*********************/

	IF NOT EXISTS (SELECT * FROM dbo.ConnParameters WHERE CollectionName='Collector.IndexStats')
	INSERT  INTO dbo.ConnParameters
			( InstanceID, CollectionName, UserName, PWord, ConnTimeout, PacketSize,
			  AppName, Asynch, AppIntent, Authentication, ConnRetryCT,
			  ConnRetryInterval, Encrypt, MultiSubnetFailover, TrustServerCert,
			  IsActive, Comment )
	VALUES (0, 'Collector.IndexStats', 'SSPI', 'SSPI', NULL, NULL, 'Minion: Collector.IndexStats', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1, 'MINION DEFAULT. DO NOT REMOVE.');
/*********************
4
*********************/

	IF NOT EXISTS (SELECT * FROM dbo.ConnParameters WHERE CollectionName='Collector.Logins')
	INSERT  INTO dbo.ConnParameters
			( InstanceID, CollectionName, UserName, PWord, ConnTimeout, PacketSize,
			  AppName, Asynch, AppIntent, Authentication, ConnRetryCT,
			  ConnRetryInterval, Encrypt, MultiSubnetFailover, TrustServerCert,
			  IsActive, Comment )
	VALUES (0, 'Collector.Logins', 'SSPI', 'SSPI', NULL, NULL, 'Minion: Collector.Logins', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1, 'MINION DEFAULT. DO NOT REMOVE.');
/*********************
5
*********************/

	IF NOT EXISTS (SELECT * FROM dbo.ConnParameters WHERE CollectionName='Collector.DBUsers')
	INSERT  INTO dbo.ConnParameters
			( InstanceID, CollectionName, UserName, PWord, ConnTimeout, PacketSize,
			  AppName, Asynch, AppIntent, Authentication, ConnRetryCT,
			  ConnRetryInterval, Encrypt, MultiSubnetFailover, TrustServerCert,
			  IsActive, Comment )
	VALUES (0, 'Collector.DBUsers', 'SSPI', 'SSPI', NULL, NULL, 'Minion: Collector.DBUsers', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1, 'MINION DEFAULT. DO NOT REMOVE.');
/*********************
6
*********************/

	IF NOT EXISTS (SELECT * FROM dbo.ConnParameters WHERE CollectionName='Collector.WaitStats')
	INSERT  INTO dbo.ConnParameters
			( InstanceID, CollectionName, UserName, PWord, ConnTimeout, PacketSize,
			  AppName, Asynch, AppIntent, Authentication, ConnRetryCT,
			  ConnRetryInterval, Encrypt, MultiSubnetFailover, TrustServerCert,
			  IsActive, Comment )
	VALUES (0, 'Collector.WaitStats', 'SSPI', 'SSPI', NULL, NULL, 'Minion: Collector.WaitStats', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1, 'MINION DEFAULT. DO NOT REMOVE.');
/*********************
7
*********************/

	IF NOT EXISTS (SELECT * FROM dbo.ConnParameters WHERE CollectionName='Collector.ServiceProperties')
	INSERT  INTO dbo.ConnParameters
			( InstanceID, CollectionName, UserName, PWord, ConnTimeout, PacketSize,
			  AppName, Asynch, AppIntent, Authentication, ConnRetryCT,
			  ConnRetryInterval, Encrypt, MultiSubnetFailover, TrustServerCert,
			  IsActive, Comment )
	VALUES (0, 'Collector.ServiceProperties', 'SSPI', 'SSPI', NULL, NULL, 'Minion: Collector.ServiceProperties', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1, 'MINION DEFAULT. DO NOT REMOVE.');
/*********************
8
*********************/

	IF NOT EXISTS (SELECT * FROM dbo.ConnParameters WHERE CollectionName='Collector.ErrorLog')
	INSERT  INTO dbo.ConnParameters
			( InstanceID, CollectionName, UserName, PWord, ConnTimeout, PacketSize,
			  AppName, Asynch, AppIntent, Authentication, ConnRetryCT,
			  ConnRetryInterval, Encrypt, MultiSubnetFailover, TrustServerCert,
			  IsActive, Comment )
	VALUES (0, 'Collector.ErrorLog', 'SSPI', 'SSPI', NULL, NULL, 'Minion: Collector.ErrorLog', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1, 'MINION DEFAULT. DO NOT REMOVE.');
/*********************
9
*********************/

	IF NOT EXISTS (SELECT * FROM dbo.ConnParameters WHERE CollectionName='Collector.DBFileProperties')
	INSERT  INTO dbo.ConnParameters
			( InstanceID, CollectionName, UserName, PWord, ConnTimeout, PacketSize,
			  AppName, Asynch, AppIntent, Authentication, ConnRetryCT,
			  ConnRetryInterval, Encrypt, MultiSubnetFailover, TrustServerCert,
			  IsActive, Comment )
	VALUES (0, 'Collector.DBFileProperties', 'SSPI', 'SSPI', NULL, NULL, 'Minion: Collector.DBFileProperties', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1, 'MINION DEFAULT. DO NOT REMOVE.');
/*********************
10
*********************/

	IF NOT EXISTS (SELECT * FROM dbo.ConnParameters WHERE CollectionName='Collector.DBProperties')
	INSERT  INTO dbo.ConnParameters
			( InstanceID, CollectionName, UserName, PWord, ConnTimeout, PacketSize,
			  AppName, Asynch, AppIntent, Authentication, ConnRetryCT,
			  ConnRetryInterval, Encrypt, MultiSubnetFailover, TrustServerCert,
			  IsActive, Comment )
	VALUES (0, 'Collector.DBProperties', 'SSPI', 'SSPI', NULL, NULL, 'Minion: Collector.DBProperties', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1, 'MINION DEFAULT. DO NOT REMOVE.');
/*********************
11
*********************/

	IF NOT EXISTS (SELECT * FROM dbo.ConnParameters WHERE CollectionName='dbo.ReplPublisher')
	INSERT  INTO dbo.ConnParameters
			( InstanceID, CollectionName, UserName, PWord, ConnTimeout, PacketSize,
			  AppName, Asynch, AppIntent, Authentication, ConnRetryCT,
			  ConnRetryInterval, Encrypt, MultiSubnetFailover, TrustServerCert,
			  IsActive, Comment )
	VALUES (0, 'dbo.ReplPublisher', 'SSPI', 'SSPI', NULL, NULL, 'Minion: dbo.ReplPublisher', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1, 'MINION DEFAULT. DO NOT REMOVE.');
/*********************
12
*********************/

	IF NOT EXISTS (SELECT * FROM dbo.ConnParameters WHERE CollectionName='Collector.MBImportAllLogs')
	INSERT  INTO dbo.ConnParameters
			( InstanceID, CollectionName, UserName, PWord, ConnTimeout, PacketSize,
			  AppName, Asynch, AppIntent, Authentication, ConnRetryCT,
			  ConnRetryInterval, Encrypt, MultiSubnetFailover, TrustServerCert,
			  IsActive, Comment )
	VALUES (0, 'Collector.MBImportAllLogs', 'SSPI', 'SSPI', NULL, NULL, 'Minion: Collector.MBImportAllLogs', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1, 'MINION DEFAULT. DO NOT REMOVE.');
/*********************
13
*********************/

	IF NOT EXISTS (SELECT * FROM dbo.ConnParameters WHERE CollectionName='dbo.MBSettingsImport')
	INSERT  INTO dbo.ConnParameters
			( InstanceID, CollectionName, UserName, PWord, ConnTimeout, PacketSize,
			  AppName, Asynch, AppIntent, Authentication, ConnRetryCT,
			  ConnRetryInterval, Encrypt, MultiSubnetFailover, TrustServerCert,
			  IsActive, Comment )
	VALUES (0, 'dbo.MBSettingsImport', 'SSPI', 'SSPI', NULL, NULL, 'Minion: dbo.MBSettingsImport', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1, 'MINION DEFAULT. DO NOT REMOVE.');
/*********************
14
*********************/

	IF NOT EXISTS (SELECT * FROM dbo.ConnParameters WHERE CollectionName='dbo.MRSettingsImport')
	INSERT  INTO dbo.ConnParameters
			( InstanceID, CollectionName, UserName, PWord, ConnTimeout, PacketSize,
			  AppName, Asynch, AppIntent, Authentication, ConnRetryCT,
			  ConnRetryInterval, Encrypt, MultiSubnetFailover, TrustServerCert,
			  IsActive, Comment )
	VALUES (0, 'dbo.MRSettingsImport', 'SSPI', 'SSPI', NULL, NULL, 'Minion: dbo.MRSettingsImport', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1, 'MINION DEFAULT. DO NOT REMOVE.');
/*********************
10014
*********************/

	IF NOT EXISTS (SELECT * FROM dbo.ConnParameters WHERE CollectionName='Collector.MRImportAllLogs')
	INSERT  INTO dbo.ConnParameters
			( InstanceID, CollectionName, UserName, PWord, ConnTimeout, PacketSize,
			  AppName, Asynch, AppIntent, Authentication, ConnRetryCT,
			  ConnRetryInterval, Encrypt, MultiSubnetFailover, TrustServerCert,
			  IsActive, Comment )
	VALUES (0, 'Collector.MRImportAllLogs', 'SSPI', 'SSPI', NULL, NULL, 'Minion: Collector.MRImportAllLogs', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1, 'MINION DEFAULT. DO NOT REMOVE.');
/*********************
10015
*********************/

	IF NOT EXISTS (SELECT * FROM dbo.ConnParameters WHERE CollectionName='Collector.AGProperties')
	INSERT  INTO dbo.ConnParameters
			( InstanceID, CollectionName, UserName, PWord, ConnTimeout, PacketSize,
			  AppName, Asynch, AppIntent, Authentication, ConnRetryCT,
			  ConnRetryInterval, Encrypt, MultiSubnetFailover, TrustServerCert,
			  IsActive, Comment )
	VALUES (0, 'Collector.AGProperties', 'SSPI', 'SSPI', NULL, NULL, 'Minion: Collector.AGProperties', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1, 'MINION DEFAULT. DO NOT REMOVE.');


		IF NOT EXISTS (SELECT * FROM dbo.ConnParameters WHERE CollectionName='MRImport')
	INSERT  INTO dbo.ConnParameters
			( InstanceID, CollectionName, UserName, PWord, ConnTimeout, PacketSize,
			  AppName, Asynch, AppIntent, Authentication, ConnRetryCT,
			  ConnRetryInterval, Encrypt, MultiSubnetFailover, TrustServerCert,
			  IsActive, Comment )
	VALUES (0, 'MRImport', 'SSPI', 'SSPI', NULL, NULL, 'Minion:MRImport', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1, 'MINION DEFAULT. DO NOT REMOVE.' );

			IF NOT EXISTS (SELECT * FROM dbo.ConnParameters WHERE CollectionName='MailInfo')
	INSERT  INTO dbo.ConnParameters
			( InstanceID, CollectionName, UserName, PWord, ConnTimeout, PacketSize,
			  AppName, Asynch, AppIntent, Authentication, ConnRetryCT,
			  ConnRetryInterval, Encrypt, MultiSubnetFailover, TrustServerCert,
			  IsActive, Comment )
	VALUES (0, 'MailInfo', 'SSPI', 'SSPI', NULL, NULL, 'Minion:MailInfo', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1, 'MINION DEFAULT. DO NOT REMOVE.' );

			IF NOT EXISTS (SELECT * FROM dbo.ConnParameters WHERE CollectionName='JobInfo')
	INSERT  INTO dbo.ConnParameters
			( InstanceID, CollectionName, UserName, PWord, ConnTimeout, PacketSize,
			  AppName, Asynch, AppIntent, Authentication, ConnRetryCT,
			  ConnRetryInterval, Encrypt, MultiSubnetFailover, TrustServerCert,
			  IsActive, Comment )
	VALUES (0, 'JobInfo', 'SSPI', 'SSPI', NULL, NULL, 'Minion:JobInfo', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1, 'MINION DEFAULT. DO NOT REMOVE.' );

	IF NOT EXISTS (SELECT * FROM dbo.ConnParameters WHERE CollectionName='WMIGeneric')
	INSERT  INTO dbo.ConnParameters
			( InstanceID, CollectionName, UserName, PWord, ConnTimeout, PacketSize,
			  AppName, Asynch, AppIntent, Authentication, ConnRetryCT,
			  ConnRetryInterval, Encrypt, MultiSubnetFailover, TrustServerCert,
			  IsActive, Comment )
	VALUES (0, 'WMIGeneric', 'SSPI', 'SSPI', NULL, NULL, 'Minion:WMIGeneric', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1, 'MINION DEFAULT. DO NOT REMOVE.' );

		IF NOT EXISTS (SELECT * FROM dbo.ConnParameters WHERE CollectionName='SQLGeneric')
	INSERT  INTO dbo.ConnParameters
			( InstanceID, CollectionName, UserName, PWord, ConnTimeout, PacketSize,
			  AppName, Asynch, AppIntent, Authentication, ConnRetryCT,
			  ConnRetryInterval, Encrypt, MultiSubnetFailover, TrustServerCert,
			  IsActive, Comment )
	VALUES (0, 'SQLGeneric', 'SSPI', 'SSPI', NULL, NULL, 'Minion:SQLGeneric', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1, 'MINION DEFAULT. DO NOT REMOVE.' );

--------------------------------------------------------------------------------------------------------------------------------------------------------------------
--------------------------------------------------------------------------------------------------------------------------------------------------------------------
----------------------------END Conn Parameters---------------------------------------------------------------------------------------------------------------------
--------------------------------------------------------------------------------------------------------------------------------------------------------------------
--------------------------------------------------------------------------------------------------------------------------------------------------------------------

INSERT dbo.TipOfDay
        (Module, Tip)
VALUES
(N'Backup', N'Only the most recent backup is considered for each availability group.' ), 
(N'Backup', N'Whenever possible, the error message is included in the alert email.  Some reasons why it wouldn''t be included are: You''re not using Minion Backup, the Minion Backup log details haven''t made their way to Minion Enterprise yet, or the backup error wasn''t captured by Minion Backup.  The theme here is that you can only get errors in the alert email if you''re using Minion Backup.' ), 
(N'Backup', N'Minion Enterprise gives you a 2nd chance to prevent false positives in your backup alerts by not only checking the latest data from Collector.DBProperties, but also by checking the Minion Backup log data as it comes in.  The Minion Backup data should be refreshed more frequently than the DBProperties data so you stand a much better chance of being accurate.' ), 
(N'Backup', N'Minion Enterprise doesn''t require you to be on Minion Backup to alert on missing backups, but you won''t get as much information and it may not be as accurate.' ), 
(N'Backup', N'Don''t make changes to Minion Backup data on your servers.  Make the changes in Minion Enterprise and let it push those changes to each server for you.' ), 
(N'Service', N'The @ServiceName parameter for the alert job can take static service names, wildcard names, or both.' ), 
(N'Service', N'The @StartMode parameter for the alert job can take Auto, Disabled, Manual, All, or NULL as inputs.  All and NULL mean the same thing.' ), 
(N'Service', N'Using the @StartMode parameter for the alert job limits the StartModes you want to alert on.  For instance, if you choose @StartMode = ''Auto'' then only jobs that aren''t running, but also have that start mode will be alerted on.' ), 
(N'Service', N'This alert uses the Collector.ServicePropertiesCurrent view, which shows the last collection for each server.  In fact, most of the Collector tables have both a Current and a Previous view.' ), 
(N'Service', N'There is also a Collector.ServicePropertiesPrevious view which shows the next to last (penultimate) collection.  Compare that with the Collector.ServicePropertiesCurrent view to build your own custom alerts.' ), 
(N'Service', N'This alert also comes with a night mode which uses dark colors to keep from blinding you if you get an alert in the middle of the night.  We think the small things matter.  The night mode kicks in at 10pm.' )

-----------------------Server Variables------------------------
IF (SELECT COUNT(*) FROM dbo.ServerVariables) = 0
BEGIN
	INSERT dbo.ServerVariables (Name, Value)
	VALUES('Report Server', @@SERVERNAME),
	('NightMode Begin', '22'),
	('NightMode End', '7'),
	('ReplPublisherAlertMethodDefault', 'Secs'),
	('ReplPublisherAlertValueDefault', '500')
END

UPDATE [dbo].[BackupSettingsServer]
      SET [Day] = 'LastOfMonth'
      WHERE [Day] = 'LastOfMont';
